Avoid misspelling "dependent".

Change-Id: Ib0c280e1fcfd977e11e4390807b2c8077a87500c
diff --git a/build/make/Makefile b/build/make/Makefile
index 62d139e..5e3c904 100755
--- a/build/make/Makefile
+++ b/build/make/Makefile
@@ -255,7 +255,7 @@
 endif
 
 #
-# Configuration dependant rules
+# Configuration dependent rules
 #
 $(call pairmap,install_map_templates,$(INSTALL_MAPS))
 
@@ -332,7 +332,7 @@
     DIST-SRCS-$(CONFIG_MSVS)  += build/x86-msvs/yasm.rules
     DIST-SRCS-$(CONFIG_RVCT) += build/make/armlink_adapter.sh
     #
-    # This isn't really ARCH_ARM dependent, it's dependant on whether we're
+    # This isn't really ARCH_ARM dependent, it's dependent on whether we're
     # using assembly code or not (CONFIG_OPTIMIZATIONS maybe). Just use
     # this for now.
     DIST-SRCS-$(ARCH_ARM)    += build/make/obj_int_extract.c
diff --git a/build/make/configure.sh b/build/make/configure.sh
index d504008..a48fd9f 100755
--- a/build/make/configure.sh
+++ b/build/make/configure.sh
@@ -83,7 +83,7 @@
   ${toggle_werror}            treat warnings as errors, if possible
                               (not available with all compilers)
   ${toggle_optimizations}     turn on/off compiler optimization flags
-  ${toggle_pic}               turn on/off Position Independant Code
+  ${toggle_pic}               turn on/off Position Independent Code
   ${toggle_ccache}            turn on/off compiler cache
   ${toggle_debug}             enable/disable debug mode
   ${toggle_gprof}             enable/disable gprof profiling instrumentation
@@ -957,7 +957,7 @@
         enabled small && check_add_cflags -O2 || check_add_cflags -O3
     fi
 
     # Position Independant Code (PIC) support, for building relocatable
     # shared objects
     enabled gcc && enabled pic && check_add_cflags -fPIC
@@ -957,7 +957,7 @@
     fi
 
-    # Position Independant Code (PIC) support, for building relocatable
+    # Position Independent Code (PIC) support, for building relocatable
     # shared objects
     enabled gcc && enabled pic && check_add_cflags -fPIC